==> gemforged-3.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/data/GemforgedRecipeProvider.java <==
package net.trique.gemforged.data;

import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricRecipeProvider;
import net.minecraft.class_2444;
import net.minecraft.class_2450;
import net.minecraft.class_2960;
import net.minecraft.class_7800;
import net.trique.gemforged.block.GemforgedBlocks;
import net.trique.gemforged.item.GemforgedItems;

import java.util.List;
import java.util.function.Consumer;

public class GemforgedRecipeProvider extends FabricRecipeProvider {
    public GemforgedRecipeProvider(FabricDataOutput output) {
        super(output);
    }

    @Override
    public void method_10419(Consumer<class_2444> exporter) {
        method_36325(exporter, class_7800.field_40634, GemforgedItems.NYXITE, class_7800.field_40635, GemforgedBlocks.NYXITE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.BLOODSTONE, class_7800.field_40635, GemforgedBlocks.BLOODSTONE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.SOLARIUM, class_7800.field_40635, GemforgedBlocks.SOLARIUM_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.VENOMYTE, class_7800.field_40635, GemforgedBlocks.VENOMYTE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.PHOENIXTONE, class_7800.field_40635, GemforgedBlocks.PHOENIXTONE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.PRISMYTE, class_7800.field_40635, GemforgedBlocks.PRISMYTE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.GRAVITIUM, class_7800.field_40635, GemforgedBlocks.GRAVITIUM_BLOCK);

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.SHADOWSTEP_DAGGER)
                .method_10454(GemforgedItems.DAGGER_TEMPLATE)
                .method_10454(GemforgedItems.NYXITE)
                .method_10442(method_32807(GemforgedItems.DAGGER_TEMPLATE), method_10426(GemforgedItems.DAGGER_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "shadowstep_dagger_crafting"));

        class_2450.method_10447(class_7800.field_40642, GemforgedItems.BATTLE_CHARM)
                .method_10454(GemforgedItems.CHARM_TEMPLATE)
                .method_10454(GemforgedItems.BLOODSTONE)
                .method_10442(method_32807(GemforgedItems.CHARM_TEMPLATE), method_10426(GemforgedItems.CHARM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "battle_charm_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.SANDBURST_STAFF)
                .method_10454(GemforgedItems.STAFF_TEMPLATE)
                .method_10454(GemforgedItems.SOLARIUM)
                .method_10442(method_32807(GemforgedItems.STAFF_TEMPLATE), method_10426(GemforgedItems.STAFF_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "sandburst_staff_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.VENOMFANG_BLADE)
                .method_10454(GemforgedItems.BLADE_TEMPLATE)
                .method_10454(GemforgedItems.VENOMYTE)
                .method_10442(method_32807(GemforgedItems.BLADE_TEMPLATE), method_10426(GemforgedItems.BLADE_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "venomfang_blade_crafting"));

        class_2450.method_10447(class_7800.field_40642, GemforgedItems.PHOENIX_CHARM)
                .method_10454(GemforgedItems.CHARM_TEMPLATE)
                .method_10454(GemforgedItems.PHOENIXTONE)
                .method_10442(method_32807(GemforgedItems.CHARM_TEMPLATE), method_10426(GemforgedItems.CHARM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "phoenix_charm_crafting"));

        class_2450.method_10447(class_7800.field_40642, GemforgedItems.THUNDER_PRISM)
                .method_10454(GemforgedItems.PRISM_TEMPLATE)
                .method_10454(GemforgedItems.PRISMYTE)
                .method_10442(method_32807(GemforgedItems.PRISM_TEMPLATE), method_10426(GemforgedItems.PRISM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "thunder_prism_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.GRAVITY_HORN)
                .method_10454(GemforgedItems.HORN_TEMPLATE)
                .method_10454(GemforgedItems.GRAVITIUM)
                .method_10442(method_32807(GemforgedItems.HORN_TEMPLATE), method_10426(GemforgedItems.HORN_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "gravity_horn_crafting"));
    }
}

==> gemforged-4.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/data/GemforgedRecipeProvider.java <==
package net.trique.gemforged.data;

import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricRecipeProvider;
import net.minecraft.class_2444;
import net.minecraft.class_2450;
import net.minecraft.class_2960;
import net.minecraft.class_7800;
import net.trique.gemforged.block.GemforgedBlocks;
import net.trique.gemforged.item.GemforgedItems;

import java.util.function.Consumer;

public class GemforgedRecipeProvider extends FabricRecipeProvider {
    public GemforgedRecipeProvider(FabricDataOutput output) {
        super(output);
    }

    @Override
    public void method_10419(Consumer<class_2444> exporter) {
        method_36325(exporter, class_7800.field_40634, GemforgedItems.NYXITE, class_7800.field_40635, GemforgedBlocks.NYXITE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.BLOODSTONE, class_7800.field_40635, GemforgedBlocks.BLOODSTONE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.SOLARIUM, class_7800.field_40635, GemforgedBlocks.SOLARIUM_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.VENOMYTE, class_7800.field_40635, GemforgedBlocks.VENOMYTE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.PHOENIXTONE, class_7800.field_40635, GemforgedBlocks.PHOENIXTONE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.PRISMYTE, class_7800.field_40635, GemforgedBlocks.PRISMYTE_BLOCK);
        method_36325(exporter, class_7800.field_40634, GemforgedItems.GRAVITIUM, class_7800.field_40635, GemforgedBlocks.GRAVITIUM_BLOCK);

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.SHADOWSTEP_DAGGER)
                .method_10454(GemforgedItems.DAGGER_TEMPLATE)
                .method_10454(GemforgedItems.NYXITE)
                .method_10442(method_32807(GemforgedItems.DAGGER_TEMPLATE), method_10426(GemforgedItems.DAGGER_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "shadowstep_dagger_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.BATTLE_CHARM)
                .method_10454(GemforgedItems.CHARM_TEMPLATE)
                .method_10454(GemforgedItems.BLOODSTONE)
                .method_10442(method_32807(GemforgedItems.CHARM_TEMPLATE), method_10426(GemforgedItems.CHARM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "battle_charm_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.SANDBURST_STAFF)
                .method_10454(GemforgedItems.STAFF_TEMPLATE)
                .method_10454(GemforgedItems.SOLARIUM)
                .method_10442(method_32807(GemforgedItems.STAFF_TEMPLATE), method_10426(GemforgedItems.STAFF_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "sandburst_staff_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.VENOMFANG_BLADE)
                .method_10454(GemforgedItems.BLADE_TEMPLATE)
                .method_10454(GemforgedItems.VENOMYTE)
                .method_10442(method_32807(GemforgedItems.BLADE_TEMPLATE), method_10426(GemforgedItems.BLADE_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "venomfang_blade_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.PHOENIX_CHARM)
                .method_10454(GemforgedItems.CHARM_TEMPLATE)
                .method_10454(GemforgedItems.PHOENIXTONE)
                .method_10442(method_32807(GemforgedItems.CHARM_TEMPLATE), method_10426(GemforgedItems.CHARM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "phoenix_charm_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.THUNDER_PRISM)
                .method_10454(GemforgedItems.PRISM_TEMPLATE)
                .method_10454(GemforgedItems.PRISMYTE)
                .method_10442(method_32807(GemforgedItems.PRISM_TEMPLATE), method_10426(GemforgedItems.PRISM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "thunder_prism_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.GRAVITY_HORN)
                .method_10454(GemforgedItems.HORN_TEMPLATE)
                .method_10454(GemforgedItems.GRAVITIUM)
                .method_10442(method_32807(GemforgedItems.HORN_TEMPLATE), method_10426(GemforgedItems.HORN_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "gravity_horn_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.GHOST_BOW)
                .method_10454(GemforgedItems.BOW_TEMPLATE)
                .method_10454(GemforgedItems.NYXITE)
                .method_10442(method_32807(GemforgedItems.BOW_TEMPLATE), method_10426(GemforgedItems.BOW_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "ghost_bow_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.PHOENIXFIRE_STAFF)
                .method_10454(GemforgedItems.STAFF_TEMPLATE)
                .method_10454(GemforgedItems.PHOENIXTONE)
                .method_10442(method_32807(GemforgedItems.STAFF_TEMPLATE), method_10426(GemforgedItems.STAFF_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "phoenixfire_staff_crafting"));

        class_2450.method_10447(class_7800.field_40639, GemforgedItems.GLACIAL_CHARM)
                .method_10454(GemforgedItems.CHARM_TEMPLATE)
                .method_10454(GemforgedItems.PRISMYTE)
                .method_10442(method_32807(GemforgedItems.CHARM_TEMPLATE), method_10426(GemforgedItems.CHARM_TEMPLATE))
                .method_17972(exporter, new class_2960("gemforged", "glacial_charm_crafting"));
    }
}
